<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Factories\Fis45000DesissBHFactory;
use Teknisa\FIS\Modules\Acessorias\Services\Fis91000ObrigacoesAcessoriasService;
use Teknisa\FIS\Modules\Acessorias\Services\Agendamento;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use \Teknisa\Libs\Util\Libraries\PHPMailer;

class Fis45000DesissBHService {

    protected $environment;
    protected $desissBHFactory;
    protected $obrigacoesService;
    
    public $mensagemBody = '';
    public $mensagemBodySucess = '';
    public $mensagemError = '';
    public $mensagemErrorBody = '';
    public $geraArquivo = '';

    public function __construct(Environment $environment, Fis45000DesissBHFactory  $desissBHFactory, 
                                Fis91000ObrigacoesAcessoriasService $obrigacoesService, NewCode $newCode ) 
    {
        $this->environment       = $environment;
        $this->desissBHFactory   = $desissBHFactory;
        $this->obrigacoesService = $obrigacoesService;
        $this->newCode           = $newCode;
    }

    /*
     * Função para criar o arquivo da exportação do DIEF-ES.
     */
    private function createFileDesissBH($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = array(
            "NRORG" => $row["NRORG"],
            "NRSEQARQMAG" => $row["NRSEQARQMAG"]
        );
        $diefESData = $this->desissBHFactory->getDesissBHData($params);

        if(isset($row['NRAGENDAMENTO']) && empty($diefESData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row["NMARQUIVO"], $diefESData, "DSREGARQMAG");

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }

    /*
     * Função para exportar o DIEF-ES.
     */
    public function exportarDesissBH($row) {
        // Busca e atribui os valores do NRORG e datas inicial e final do mês
        // à variável row.
        $nrorg = $this->environment->getNrorg();
        $datas = $this->obrigacoesService->getFirstAndLastDays($row["DTREFINI"]);
        $row["DTINICIAL"] = $datas["DTINICIAL"];
        $row["DTFINAL"] = $datas["DTFINAL"];
        $row["NRORG"] = $nrorg;
        // Gera o próximo código sequencial do arquivo magnético.
        $row["NRSEQARQMAG"] = $this->obrigacoesService->getNextNrseqarqmag($row["NRORG"]);
        $row["CDLIVROMAG"] = null;
        // Chama a procedure de exportação.
        $this->desissBHFactory->callExportacaoProcedure($row);

        // Foi evitado utilizar um bloco finally devido a possíveis
        // incompatibilidades com a versão do PHP.
        try{
            // Seta os parâmetros para exclusão dos dados temporários.
            $params = array(
                "NRORG" => $row["NRORG"],
                "NRSEQARQMAG" => $row["NRSEQARQMAG"]
            );
            // Chama a função para gerar o arquivo texto.
            $fileName = $this->createFileDesissBH($row);
            // Exclui os dados temporários da exportação no banco de dados.
            $this->desissBHFactory->deleteDesissBH($params);

            // Retorna o nome do arquivo com suas possíveis modificações.
            return $fileName;
        } catch(\Exception $e) {
            // Exclui os dados temporários da exportação no banco de dados.
            $this->desissBHFactory->deleteDesissBH($params);
            throw $e;
        }
    }
    
}